كانون گفتگوی قرآنی
Description: احكام,آموزش,مشاوره,خداشناسي,قرآن,معاد,مناظره,تحدي,محكم,متشابه,تفسير,تحریف
Keywords: قرآن,پاسخگویی,مرکز ملی پاسخگویی,کتابخانه,گالری,دین,احکام,نرم افزار,دانلود,فیلم

- ثبت نام
- ذخیره؟

اَلسَّلامُ عَلَیکَ وَ عَلی الَأرواحِ الَّتِی حَلَتْ بِفِنآئِکَ عَلَیکُمْ مِنْی جَمِیعاً سَلامُ اللهِ اَبداً ما بَقَیتُ وَ بَقِیَ الَّلیلِ وَ النَّهارُ یا اَبا عَبدِ اللِه، لَقَدْ عَظُمَتِ الرَّزِیَّةُ وَ جَلَتْ وَ عَظُمَتِ الُمصیبَةُ بِکَ عَلَینْا وَ عَلی جَمیِع اَهْلِ الِأسْلِام

1. ضمن عرض خوش آمد گویی با توجه به کاربر محور بودن انجمن همه مطالب سایت مورد تائید نمی باشد و نام کاربری کارشناسان سایت با رنگ آبی و سبز مشخص شده است.
2. برای دریافت پیام های سایت از طریق ایمیل و عضویت در گروه کانون گفتگوی قرآنی از این لینک اقدام فرمائید
3. لطفا بعد از واردشدن در جیمیل و کلیک بر آیکن گوگل +1 گفتگوی قرآنی را در جستجوی گوگل ارتقاء دهید توضیح : اینجا . تعداد حمایت ها :
4. برای آموزش حفظ قرآن کلیک کنید
5. ▌▬◄مسابقه "جام حذفی سوالات قرآنی"►▬▐
6. نقد فقهی استدلال تکفیری‎ها و داعشی‌ها بر اولویت کشتن مسلمانان مخالف آنها
7. "ان الحسین مصباح الهدی و سفینة النجاة" ویژه نامه محرم 1437
8. ۞۞۞دانلود نرم افزار آداب و احکام عزاداری اندروید محصول جدید سایت۞۞۞
9. غریب مدینه -ویژه نامه شهادت امام حسن مجتبی علیه السلام
10. ***مسابقه ی عکس نوشته با موضوع " اربعین حسینی "***
11. کانال رسمی کانون گفتگوی قرانی در تلگرام ایجاد شد+عضویت
12. ◕✿◕دانلود نرم افزار پاسخ به شبهات اربعین اندروید محصول جدید سایت◕✿◕

- رسول خدا (ص) : صلوات ، فقر را برطرف میکند
- رسول خدا (ص) : هر که یک مرتبه بر من صلوات فرستد، حق‌تعالی دری از سلامتی و عافیت [دین و دنیا] را بر وی بگشاید
- رسول خدا (ص) : هر كه بر من صلوات فرستد خدا و فرشتگان بر او صلوات فرستند، هر كه خواهد كم فرستد و هر كه خواهد بيش
- رسول خدا (ص) : هرکس یک مرتبه بر من صلوات بفرستد ، آن دو ملکی که محافظ رفتار او هستند ، تا سه روز هیچ گناهی برای او نمی نویسند
- امام صادق (ع) :هر دعایی که خدای متعال با آن خوانده شود، بالا نمی رود مگر آنکه بر محمّد و آل محمّد صلوات فرستاده شود
- رسول خدا (ص) : هر کس بر من صلوات زیاد بفرستد از تلخی مرگ و جان کندن ایمن گردد
- رسول خدا (ص) : بر من بسیار صلوات بفرستید که صلوات بر من نوری در قبر، نوری در پل صراط و نوری در بهشت خواهد بود
- امام صادق (ع) :صلوات بر پیامبر (ص) و آل او ،‏ سنگین ترین عملی است که در روز قیامت در ترازوی اعمال گذاشته می شود
- رسول خدا (ص) : در قیامت نزدیک ترین مردم به من کسی است که بیشتر بر من صلوات بفرستد
- رسول خدا (ص) : هر کس چیزی را فراموش کرد، بر من صلوات بفرستد، تا آن موضوع یادش بیاید
- امام صادق (ع) :فرستادن صلوات بین نماز ظهر و عصر برابر است با هفتاد رکعت نماز مستحبی
- امام صادق (ع) :هرکه صد بار صلوات بفرستد، صد نیاز برایش برآورند، سی در دنیا هفتاد در آخرت

| گمنام110 : صلوات 1000 بار ❤ اللهم عجل لوليك الفرج مهمان : صلوات 1000 بار ❤ قال رسول الله: أحَبَّ اللهُ مَن أحَبَّ حُسَيناً. كامل الزيارات 52 باب 14 حديث 11 دلاور : صلوات 10 بار ❤ مهمان : صلوات 5 بار ❤ ان شاالله به زودی کربلا باشم وکتابم وداداشم ودرسام ومامانم وبابام وملتمسین دعاکه خودتون می دونید مهمان : صلوات 100 بار ❤ ان شا ئ الله جامعه قبول شوم مهمان : صلوات 10 بار ❤ http://www.askquran.ir/images/smilies/smile.png گمنام110 : صلوات 500 بار ❤ دلم خوش است به مستحبي كه جوابش واجب است... ....السلام عليك يابن فاطمه يا صاحب الزمان.... گمنام110 : صلوات 500 بار ❤ آمدنت را آرزو نميكنم... آرزو ميكنم وقتي آمدي ،چشمانم شرمنده ي نگاهت نباشد... اللهم عجل لوليك الفرج.. مهمان : صلوات 12 بار ❤ Ali مهمان : صلوات 12 بار ❤ علي

| ختم 300,000,000 صلوات |  |  | مشارکت : 115,427,015 صلوات | مانده : 184572985 صلوات

- ## آخرین ارسال ها

1. ## انجمن آموزش و قرائت قرآن

   1. ## آموزش

      (2 کاربر آنلاین)

      #### بخشها:

      1. - حافظان قرآن
         - حفظ قرآن
         - روخوانی و روانخوانی
         - آموزش حفظ کودکان

      #### مدیران انجمن:

      1. گلستان قرآن

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 68
      - نوشته: 13,953

      #### آخرين نوشته:

      طرح انس با قرآن // حفظ موضوعی...

      توسط
      خاتم
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      13/09/1394, 10:08

   2. ## قرائت

      (17 کاربر آنلاین)

      #### بخشها:

      1. - قرائت
         - تواشیح
         - نغمات و دستگاهای قرآنی
         - دعاهای قرآنی

      #### مدیران انجمن:

      1. گلستان قرآن

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 390
      - نوشته: 14,974

      #### آخرين نوشته:

      *** دلنوشته های شما در غروب...

      توسط
      فدایی رهبر *
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      13/09/1394, 14:30

2. ## انجمن علوم قرآنی

   1. ## وحی

      (3 کاربر آنلاین)

      #### بخشها:

      1. - اقسام وحي
         - كيفيت نزول وحي
         - زبان قرآن
         - زبان وحی
         - اسباب و شان نزول وحي

      #### مدیران انجمن:

      1. Partofar,
      2. علی ولی زاده

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 84
      - نوشته: 1,132

      #### آخرين نوشته:

      معنا شناسی واژگان و الفاظ قرآن

      توسط
      hg1478
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ
      - مشاهده صفحه اصلی

      17/08/1394, 11:20

   2. ## اعجاز

      (8 کاربر آنلاین)

      #### بخشها:

      1. - معجزه
         - معجزات پیامبر
         - اعجاز قرآن
         - تحدی و هم آورد طلبی قرآن
         - دیدگاههای مختلف در باره اعجاز
         - مقایسه قرآن با سایر کتب آسمانی
         - پيشگويي هاي قرآن
         - سایر موارد

      #### مدیران انجمن:

      1. Partofar,
      2. علی ولی زاده

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 419
      - نوشته: 9,563

      #### آخرين نوشته:

      چرا خداوندی که خوبی ما رو...

      توسط
      معین
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      08/09/1394, 17:54

   3. ## نزول قرآن

      (28 کاربر آنلاین)

      #### بخشها:

      1. - شان نزول سوره ها
         - آیات مکی و مدنی
         - سور ه ها و آیات
         - ترتیب نزول سوره ها و آیات
         - محکم و متشابه

      #### مدیران انجمن:

      1. Partofar,
      2. علی ولی زاده

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 220
      - نوشته: 2,673

      #### آخرين نوشته:

      ***** همراه با قران + همگام...

      توسط
      صادق
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      08/09/1394, 10:00

   4. ## جمع آوری قرآن

      (6 کاربر آنلاین)

      #### بخشها:

      1. - کیفیت جمع قرآن در زمان پیامبر اکرم
         - حفظ و جمع قرآن در عصر صحابه
         - کاتبان و حافظان وحی
         - مصحف امام علی
         - قراء و قرائات هفتگانه
         - قرائت ها و حدیث سبعه احروف
         - حجیت قرائات هفتگانه

      #### مدیران انجمن:

      1. Partofar,
      2. علی ولی زاده

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 89
      - نوشته: 1,380

      #### آخرين نوشته:

      كداميك از صحابه پيامبر ص دو...

      توسط
      میقات
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      13/09/1394, 14:41

   5. ## مصونیت قرآن از تحریف

      #### بخشها:

      1. - معنا و اقسام تحریف
         - عقیده مسلمانان در تحریف
         - دلایل عدم تحریف قرآن
         - عدم تحریف قرآن در روایات اسلامی

      #### مدیران انجمن:

      1. Partofar,
      2. علی ولی زاده

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 25
      - نوشته: 338

      #### آخرين نوشته:

      تناقضات قران

      توسط
      میقات
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      03/09/1394, 11:07

   6. ## نسخ

      #### بخشها:

      1. - معنای نسخ
         - انواع نسخ
         - آیات ناسخ و منسوخ

      #### مدیران انجمن:

      1. Partofar,
      2. علی ولی زاده

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 5
      - نوشته: 39

      #### آخرين نوشته:

      معنای نسخ

      توسط
      منتظرين
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      17/04/1394, 13:39

3. ## انجمن تفسیر و ترجمه قرآن

   1. ## تفسیر

      (32 کاربر آنلاین)

      #### بخشها:

      1. - ضررورت و اهمیت تفسیر قرآن
         - معنای تفسیر
         - علم تفسیر
         - انواع تفسیر
         - معیار و قواعد تفسیر
         - مبانی و روش های تفسیری
         - تفسیر ترتیبی
         - آیات
         - سوره ها
         - تفسیر موضوعی
         - اصول دین
         - فروع دین
         - تفاسیر شیعه
         - تفاسیر اهل سنت
         - معرفی مفسران معروف

      #### مدیران انجمن:

      1. محب مهدی,
      2. شیعه اهل بیت(ع),
      3. مطهره111

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 1,473
      - نوشته: 36,527

      #### آخرين نوشته:

      چرا پاداش زهد در قرآن حوری...

      توسط
      میقات
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      13/09/1394, 00:15

   2. ## تاویل قرآن

      (1 کاربر آنلاین)

      #### بخشها:

      1. - تفاوت تفسیر و تاویل
         - هرمنوتیک و قرآن
         - قرآن و فرهنگ زمانه

      #### مدیران انجمن:

      1. محب مهدی,
      2. شیعه اهل بیت(ع),
      3. مطهره111

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 259
      - نوشته: 13,715

      #### آخرين نوشته:

      *^★^* محادثه بر وزن مشاعره...

      توسط
      علی ولی زاده
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      13/09/1394, 14:08

   3. ## ترجمه

      (2 کاربر آنلاین)

      #### بخشها:

      1. - کلیات ترجمه
         - ضرورت ترجمه
         - قواعد ترجمه
         - انواع ترجمه
         - ویژگی بهترین ترجمه
         - ثواب ترجمه
         - آداب ترجمه
         - آموزش ترجمه و مفاهیم قرآن کریم
         - زندگی نامه مترجمان معروف

      #### مدیران انجمن:

      1. محب مهدی,
      2. شیعه اهل بیت(ع),
      3. مطهره111

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 124
      - نوشته: 1,731

      #### آخرين نوشته:

      قواعد ترجمه

      توسط
      شقایق
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      07/08/1394, 19:58

4. ## انجمن معارف قرآنی

   1. ## خدا شناسی در قرآن

      (1 کاربر آنلاین)

      #### بخشها:

      1. - دلایل اثبات خدا در قرآن
         - عدل الهی در قرآن
         - قضا و قدر در قرآن
         - اسماء و صفات خدا در قرآن
         - جبر و اختیار از نظر قرآن

      #### مدیران انجمن:

      1. سالار زینب

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 84
      - نوشته: 1,572

      #### آخرين نوشته:

      وقتی انسان هیچ چاره ای جز...

      توسط
      مسلم
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      12/07/1394, 13:40

   2. ## راهنما شناسی و نبوت در قرآن

      (5 کاربر آنلاین)

      #### بخشها:

      1. - نبوت خاصه
         - نبوت عامه

      #### مدیران انجمن:

      1. سالار زینب

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 217
      - نوشته: 3,619

      #### آخرين نوشته:

      آيا حضرت موسي قبل از رسالتش...

      توسط
      مسلم
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      09/09/1394, 15:46

   3. ## امامت و ولایت در قرآن

      (11 کاربر آنلاین)

      #### بخشها:

      1. - فلسفه امامت در قرآن
         - اهل بیت و ائمه در قرآن
         - مهدویت و امام زمان در قرآن
         - وعده حکومت جهانی در قرآن
         - قیام امام مهدی از نظر آیات

      #### مدیران انجمن:

      1. سالار زینب

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 1,182
      - نوشته: 18,136

      #### آخرين نوشته:

      ܓ✿ تکالیف عصر غیبتܓ✿

      توسط
      منتظر منجی(عج)
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      13/09/1394, 13:34

   4. ## معاد در قرآن

      (17 کاربر آنلاین)

      #### بخشها:

      1. - ضرورت معاد
         - چیستی و فلسفه معاد در قرآن
         - مرگ و برزخ در قرآن
         - قیامت
         - دلایل رستاخیز
         - بهشت و جهنم

      #### مدیران انجمن:

      1. سالار زینب

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 327
      - نوشته: 4,714

      #### آخرين نوشته:

      ◕◕◕ اگه نمیترسی کلیک...

      توسط
      فریده بنده مخلص خدا
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      07/09/1394, 02:37

   5. ## ادیان و فرق در قرآن

      (2 کاربر آنلاین)

      #### بخشها:

      1. - قرآن و معرفی ادیان
         - قرآن و معرفی فرق و مذاهب

      #### مدیران انجمن:

      1. سالار زینب

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 160
      - نوشته: 2,208

      #### آخرين نوشته:

      نقد فقهی استدلال تکفیری‎ها و...

      توسط
      مدیر سایت
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      29/06/1394, 23:25

   6. ## فروع دین در قرآن

      (1 کاربر آنلاین)

      #### مدیران انجمن:

      1. سالار زینب

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 14
      - نوشته: 125

      #### آخرين نوشته:

      جمع بندی آیالعن و نفرین درزیارت عاشورا...

      توسط
      مسلم
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      11/02/1394, 09:40

   7. ## انسان شناسی در قرآن

      (1 کاربر آنلاین)

      #### مدیران انجمن:

      1. سالار زینب

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 108
      - نوشته: 1,654

      #### آخرين نوشته:

      سوال در مورد چشم برزخی

      توسط
      ولایت پذیر
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ
      - مشاهده صفحه اصلی

      06/09/1394, 22:42

   8. ## خلقت انسان

      #### مدیران انجمن:

      1. سالار زینب

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 31
      - نوشته: 625

      #### آخرين نوشته:

      هدف از آفرينش انسان چيست ؟

      توسط
      دختر بسیجی
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      09/05/1394, 15:05

   9. ## حیات دنیوی انسان

      #### مدیران انجمن:

      1. سالار زینب

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 17
      - نوشته: 215

      #### آخرين نوشته:

      سخنان ناب (لابه لای گفته ها)

      توسط
      فریده بنده مخلص خدا
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      11/09/1394, 03:09

   10. ## سایر مباحث اعتقادی در قرآن

       (15 کاربر آنلاین)

       #### مدیران انجمن:

       1. سالار زینب

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 409
       - نوشته: 6,421

       #### آخرين نوشته:

       راز آفرينش از آغاز خلقت تا...

       توسط
       یوسف
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       26/08/1394, 18:11

5. ## کلام و عقاید

   1. ## مباحث کلی وجود و معرفت شناسی

      (1 کاربر آنلاین)

      #### بخشها:

      1. - وجود و ویژگی های آن
         - امکان یا عدم امکان شناخت
         - حدود و ابزار شناخت

      #### مدیران انجمن:

      1. شهیده,
      2. kobra,
      3. سعادتمند

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 78
      - نوشته: 1,240

      #### آخرين نوشته:

      چرا علم (science) لزوما حقیقت...

      توسط
      مسلم
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      09/09/1394, 11:01

   2. ## خدا شناسی

      (6 کاربر آنلاین)

      #### بخشها:

      1. - اثبات وجود خدا
         - صفات الهی
         - عدل الهی
         - قضا و قدر - جبر و اختیار
         - مباحث عبادي

      #### مدیران انجمن:

      1. أسئلونی,
      2. شهیده,
      3. kobra,
      4. سعادتمند

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 534
      - نوشته: 12,461

      #### آخرين نوشته:

      سوال در موردکاربرد صحیح قواعد...

      توسط
      میقات
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      06/09/1394, 21:32

   3. ## راهنما شناسی

      (11 کاربر آنلاین)

      #### بخشها:

      1. - علل نیاز به راهنما (نبی و امام)
         - ویژگی های پیامبران و امامان
         - خاتمیت و مسائل مربوط به پیامبر اسلام (ص)
         - نصب امام و عصمت ایشان
         - مسائل مربوط به اهل بیت و ائمه اطهار عليهم السلام
         - مهدویت
         - ولایت فقیه و حکومت اسلامی

      #### مدیران انجمن:

      1. عاشق کربلا,
      2. شهیده,
      3. kobra,
      4. سعادتمند

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 330
      - نوشته: 5,402

      #### آخرين نوشته:

      ***** زیارت اربعین +ایمان =...

      توسط
      فریده بنده مخلص خدا
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      10/09/1394, 19:56

   4. ## دین شناسی

      (9 کاربر آنلاین)

      #### بخشها:

      1. - مفهوم کلی دین
         - جهان بینی و ایدئولوژی
         - اسلام و مذاهب و فرقه ها ی مرتبط با آن
         - ادیان آسمانی و اصول آنها
         - ارتباط علم و دین و سایر مباحث
         - ادیان و فرق و مکاتب غیر آسمانی
         - بهايي پژوهي

      #### مدیران انجمن:

      1. شهیده,
      2. kobra,
      3. سعادتمند

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 459
      - نوشته: 7,715

      #### آخرين نوشته:

      چگونه قیام کنیم؟

      توسط
      مسلم
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      09/09/1394, 10:39

   5. ## فرجام شناسی (انسان بعد از دنیا)

      (1 کاربر آنلاین)

      #### بخشها:

      1. - نفس شناسی و مسائل روح
         - مرگ، حشر و اثبات عقلي معاد
         - معاد در قرآن و احادیث و روایات
         - برزخ ٫ مشخصات اخرت و ارتباط ان با دنيا
         - مساله شفاعت

      #### مدیران انجمن:

      1. شهیده,
      2. kobra,
      3. سعادتمند

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 22
      - نوشته: 220

      #### آخرين نوشته:

      همه چطوری توسط عزرائیل قبض...

      توسط
      فریده بنده مخلص خدا
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      01/08/1394, 00:55

   6. ## جهان شناسی

      (1 کاربر آنلاین)

      #### بخشها:

      1. - انسان شناسی
         - فرشتگان و ملائکه
         - جن
         - مباحث کلی طبیعت
         - سرنوشت جهان

      #### مدیران انجمن:

      1. شهیده,
      2. kobra,
      3. سعادتمند

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 21
      - نوشته: 348

      #### آخرين نوشته:

      سربازان نابود شده در آسمان چه...

      توسط
      مهدی49
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      13/09/1394, 14:12

   7. ## سایر موارد

      (2 کاربر آنلاین)

      #### بخشها:

      1. - مناظرات
         - آرشیو

      #### مدیران انجمن:

      1. شهیده,
      2. kobra,
      3. سعادتمند

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 231
      - نوشته: 4,056

      #### آخرين نوشته:

      ماجرای نامه یک دختر به امام...

      توسط
      حق گو
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      06/08/1394, 09:33

6. ## اعلام قرآن و تاريخ گذشتگان

   1. ## حکومت ها ، اقوام و ملل و سنت های در قرآن

      (6 کاربر آنلاین)

      #### مدیران انجمن:

      1. آفرینـــــش,
      2. خاتون عشق

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 181
      - نوشته: 2,160

      #### آخرين نوشته:

      ارض المقدسة

      توسط
      تذکره
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      08/07/1394, 00:55

   2. ## مكان ها ، اشخاص و سرنوشت آن ها در قرآن

      (5 کاربر آنلاین)

      #### مدیران انجمن:

      1. آفرینـــــش,
      2. خاتون عشق

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 317
      - نوشته: 3,789

      #### آخرين نوشته:

      آیا پیامبر(ص) دستور به قتل...

      توسط
      مقداد
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      07/09/1394, 11:34

   3. ## دشمن شناسی و سایر مباحث تاریخی

      (6 کاربر آنلاین)

      #### بخشها:

      1. - سایر مباحث تاریخی
         - دشمن شناسی

      #### مدیران انجمن:

      1. آفرینـــــش,
      2. خاتون عشق

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 512
      - نوشته: 8,382

      #### آخرين نوشته:

      سر بریده‌اش گردانده شد و آب...

      توسط
      مدیر محتوایی نرم افزارها
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      25/08/1394, 06:48

7. ## اخلاق و عرفان

   1. ## اخلاق

      (20 کاربر آنلاین)

      #### مدیران انجمن:

      1. بی ریا

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 1,315
      - نوشته: 32,572

      #### آخرين نوشته:

      یک مدیر تارک الصلاه چه بر سر...

      توسط
      معین
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      13/09/1394, 08:39

   2. ## عرفان ناب

      (9 کاربر آنلاین)

      #### مدیران انجمن:

      1. بی ریا

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 677
      - نوشته: 17,637

      #### آخرين نوشته:

      هرروز اینجا استغفار کنیم : ...

      توسط
      فدایی رهبر *
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      13/09/1394, 12:45

   3. ## نقد مكتب هاي اخلاقي و عرفاني

      (1 کاربر آنلاین)

      #### مدیران انجمن:

      1. بی ریا

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 126
      - نوشته: 1,907

      #### آخرين نوشته:

      کابالا

      توسط
      یوسف
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      26/08/1394, 18:29

   4. ## افلاکیان

      (7 کاربر آنلاین)

      #### بخشها:

      1. - حوزه و روحانيت
         - افلاکیان خاک نشین

      #### مدیران انجمن:

      1. بی ریا

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 299
      - نوشته: 4,309

      #### آخرين نوشته:

      بر بال اندیشه های ناب

      توسط
      یوسف .
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      24/07/1394, 07:55

   5. ## آسمانيان

      (6 کاربر آنلاین)

      #### بخشها:

      1. - برگی از دفتر زندگی ( زندگی نامه و خاطرات شهدا)
         - کلام ماندگار ( وصیت نامه و سخنان شهدا)
         - نگارخانه خاكي
         - معرفی عملیات ها و مناطق جنگی

      #### مدیران انجمن:

      1. باران,
      2. بی ریا

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 735
      - نوشته: 9,920

      #### آخرين نوشته:

      مصطفی...

      توسط
      راهیان عشق
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      08/09/1394, 17:15

   6. ## آرشیو

      #### مدیران انجمن:

      1. بی ریا

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 62
      - نوشته: 2,461

      #### آخرين نوشته:

      ♥*♥ ای زمین و آسمانها سوگوار...

      توسط
      منتظر منجی(عج)
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      16/08/1394, 19:33

8. ## احكام قرآني

   1. ## آیات الاحکام

      #### مدیران انجمن:

      1. *عرفانی*,
      2. ره روی فاطمه

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 24
      - نوشته: 206

      #### آخرين نوشته:

      آيا تقلید در زمان پيامبرصلی...

      توسط
      یوسف .
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      15/03/1394, 08:14

   2. ## پرسش وپاسخ احكام قرآني

      (38 کاربر آنلاین)

      #### بخشها:

      1. - اجتهاد و تقلید
         - طهارت و مطهرات
         - نماز
         - روزه
         - اعتکاف
         - حج
         - جهاد، دفاع و امر به معروف و نهی از منکر
         - خمس، زکات و صدقه
         - احکام اموال
         - احکام معاملات
         - احکام ازدواج و روابط زن و مرد
         - احکام معاشرت
         - احکام جزایی و کیفری
         - احکام قسم، نذرو عهد
         - احکام خوردن و آشامیدن
         - موسیقی ، قمار، شطرنج ، مسابقات و سرگرمی ها و...
         - ساير موارد

      #### مدیران انجمن:

      1. *عرفانی*,
      2. ره روی فاطمه

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 903
      - نوشته: 17,951

      #### آخرين نوشته:

      *** اخبار جهادي ***

      توسط
      آیینه دار
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      09/09/1394, 19:19

9. ## مهارتهای زندگی قرآنی

   1. ## حجاب و پوشش اسلامي

      (6 کاربر آنلاین)

      #### مدیران انجمن:

      1. منتظرمهدی زهرا,
      2. شیوا83,
      3. صدیقه طاهره,
      4. منتظران ظهور

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 449
      - نوشته: 15,322

      #### آخرين نوشته:

      من چادرم را دوست دارم...

      توسط
      راهیان عشق
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      08/09/1394, 21:25

   2. ## ازدواج و خانواده

      (7 کاربر آنلاین)

      #### بخشها:

      1. - انتخاب همسر
         - نامزدي و دوران عقد
         - مسائل خانواده
         - وظايف پدرو مادر

      #### مدیران انجمن:

      1. صدیقه طاهره,
      2. منتظران ظهور

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 622
      - نوشته: 18,046

      #### آخرين نوشته:

      اصول مهم در ازدواج موفق

      توسط
      نشاط
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      13/09/1394, 14:33

   3. ## نوجوان و جوان

      (5 کاربر آنلاین)

      #### بخشها:

      1. - ويژگي هاي دوران جواني و نوجواني
         - گرايشهاي ديني ومعنوي
         - نوجوان ، جوان و جامعه

      #### مدیران انجمن:

      1. صدیقه طاهره,
      2. منتظران ظهور

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 291
      - نوشته: 6,956

      #### آخرين نوشته:

      ***** نماز = گفتگوی دلبرانه...

      توسط
      صادق
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      09/09/1394, 12:29

   4. ## کودک

      (11 کاربر آنلاین)

      #### بخشها:

      1. - کودک و خانواده
         - کودک و رسانه ها
         - کودک و دین

      #### مدیران انجمن:

      1. خادم الزینب,
      2. فریده بنده مخلص خدا,
      3. صدیقه طاهره,
      4. منتظران ظهور

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 314
      - نوشته: 5,844

      #### آخرين نوشته:

      .•*♥*•زائران کوچک حسینی •*♥*•

      توسط
      خادم الزینب
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      11/09/1394, 00:45

   5. ## سایر مباحث

      (6 کاربر آنلاین)

      #### مدیران انجمن:

      1. حدیث 74,
      2. صدیقه طاهره,
      3. منتظران ظهور

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 376
      - نوشته: 7,474

      #### آخرين نوشته:

      جملات پر انرژی!!

      توسط
      صادق
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      12/09/1394, 12:47

   6. ## حقوق و جایگاه زن در قرآن

      (4 کاربر آنلاین)

      #### مدیران انجمن:

      1. اهورانی,
      2. صدیقه طاهره,
      3. منتظران ظهور

      #### عملیات انجمن:

      - مشاهده RSS feed این انجمن

      #### آمار انجمن:

      - موضوع: 227
      - نوشته: 4,699

      #### آخرين نوشته:

      آقایان ،بایدبدانند

      توسط
      علی ولی زاده
      - نمایش مشخصات
      - مشاهده نوشته ها
      - پیام شخصی
      - مشاهده وبلاگ

      11/09/1394, 19:05

10. ## انجمن فرهنگی

    1. ## فرهنگی

       (31 کاربر آنلاین)

       #### بخشها:

       1. - حکایت، داستان و درس هایی از قرآن
          - قرآن و اهل بیت
          - لطایف و معماهای قرآنی
          - شعر و ادبیات قرآنی
          - ویژه نامه های قرآنی
          - محرم و صفر
          - ماه مبارک رمضان
          - طرح ها و مسابقات قرآنی
          - هنرمندان و قرآن پژوهان
          - حافظان و خادمان

       #### مدیران انجمن:

       1. منتظر یوسف زهرا,
       2. شقایق

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 2,056
       - نوشته: 88,094

       #### آخرين نوشته:

       ***مسابقه ی عکس نوشته با...

       توسط
       arsalani
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       13/09/1394, 13:18

    2. ## خدمات آموزش فنی و رایانه ای

       #### بخشها:

       1. - مشکلات رایانه ای کاربران
          - پرسش و پاسخ های فنی و رایانه ای
          - سایر موارد

       #### مدیران انجمن:

       1. amirreza1373000,
       2. شقایق

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 16
       - نوشته: 395

       #### آخرين نوشته:

       آنچه بايد يك مدير سايت بداند

       توسط
       شقایق
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       22/08/1394, 20:08

    3. ## ولایت و پایداری

       (2 کاربر آنلاین)

       #### بخشها:

       1. - ولایت در قرآن
          - انقلاب اسلامی
          - جهاد و دفاع مقدس در قرآن
          - شهادت و ایثار در قرآن

       #### مدیران انجمن:

       1. طاهره,
       2. شقایق

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 479
       - نوشته: 8,069

       #### آخرين نوشته:

       امام حسین (ع)- شهادت و عشق به...

       توسط
       شقایق
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       11/09/1394, 11:30

    4. ## کتابخانه فرهنگی

       (7 کاربر آنلاین)

       #### بخشها:

       1. - مقالات و پژوهش هاي نوآمد قرآني
          - معرفی کتاب و مجلات قرآنی
          - پایگاههای قرآن
          - اخبار قرآنی

       #### مدیران انجمن:

       1. شقایق

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 581
       - نوشته: 20,870

       #### آخرين نوشته:

       مُبلغ این کتاب هستم [سلام بر...

       توسط
       گمنام110
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       11/09/1394, 16:02

    5. ## پاتوق اعضا

       (14 کاربر آنلاین)

       #### بخشها:

       1. - گروه های دسته جمعی
          - دل نوشته ، دعا و مناجات
          - سایر موارد

       #### مدیران انجمن:

       1. شقایق

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 1,743
       - نوشته: 113,184

       #### آخرين نوشته:

       مشاعره (مراعات مطلع اشعار با...

       توسط
       علی ولی زاده
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       13/09/1394, 14:02

    6. ## کلیپ صوتی ؛ تصویری و فلش

       (21 کاربر آنلاین)

       #### بخشها:

       1. - قرآن
          - کلیپ صوتی
          - فلش
          - کلیپ تصویری

       #### مدیران انجمن:

       1. شهید گمنام,
       2. شقایق

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 461
       - نوشته: 7,164

       #### آخرين نوشته:

       نواهای اربعین

       توسط
       شهید گمنام
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ
       - مشاهده صفحه اصلی

       10/09/1394, 19:40

    7. ## نگارخانه

       (5 کاربر آنلاین)

       #### بخشها:

       1. - تصاویر دیدنی
          - تصاویر قرآنی

       #### مدیران انجمن:

       1. شقایق

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 340
       - نوشته: 33,264

       #### آخرين نوشته:

       عکس متحرک (گوناگون)

       توسط
       شقایق
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       12/09/1394, 23:07

    8. ## تلفن همراه

       (4 کاربر آنلاین)

       #### بخشها:

       1. - کلیپ صوتی- تصویری
          - تم و پس زمینه
          - پیامک

       #### مدیران انجمن:

       1. شهید گمنام,
       2. شقایق

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 281
       - نوشته: 10,626

       #### آخرين نوشته:

       پیامک های تسلیت شهادت جانسوز...

       توسط
       منتظر منجی(عج)
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       26/08/1394, 14:37

11. ## انجمن نرم افزار

    1. ## موبایل

       (4 کاربر آنلاین)

       #### بخشها:

       1. - نرم افزار مذهبی و قرآنی موبایل

       #### مدیران انجمن:

       1. seyed yasin,
       2. بهار ♥ها,
       3. iranproud

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 203
       - نوشته: 1,954

       #### آخرين نوشته:

       【ツ】ترفندهای کاربردی برای...

       توسط
       شقایق
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       23/08/1394, 05:18

    2. ## نرم افزارهای رایانه ای

       (5 کاربر آنلاین)

       #### بخشها:

       1. - نرم افزارهای مذهبی و قرآنی
          - نرم افزارهای کاربردی

       #### مدیران انجمن:

       1. seyed yasin,
       2. بهار ♥ها,
       3. iranproud

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 220
       - نوشته: 1,347

       #### آخرين نوشته:

       ❀◕‿◕❀نرم افزارهای درخواستی...

       توسط
       Assistant
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       01/09/1394, 15:56

    3. ## خدمات و آموزش های نرم افزاری

       (3 کاربر آنلاین)

       #### بخشها:

       1. - آموزش نرم افزاری
          - پاسخگویی به مشکلات نرم افزاری

       #### مدیران انجمن:

       1. seyed yasin,
       2. بهار ♥ها,
       3. iranproud

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 263
       - نوشته: 3,246

       #### آخرين نوشته:

       آموزش نرم افزار فتوشاپ

       توسط
       montazer59
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       09/08/1394, 18:21

    4. ## اینترنت

       #### بخشها:

       1. - ساخت و توسعه وبلاگ و وبسایت
          - قالب سایت و وبلاگ

       #### مدیران انجمن:

       1. seyed yasin,
       2. بهار ♥ها,
       3. iranproud

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 53
       - نوشته: 514

       #### آخرين نوشته:

       چند نکته طلایی درباره طراحی...

       توسط
       shima77
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       05/08/1394, 11:23

    5. ## ویترین تولیدات و محصولات کانون گفتگوی قرآنی

       (1 کاربر آنلاین)

       #### مدیران انجمن:

       1. seyed yasin,
       2. بهار ♥ها,
       3. iranproud

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 77
       - نوشته: 1,320

       #### آخرين نوشته:

       ◕✿◕دانلود نرم افزار پاسخ به...

       توسط
       مدیر محتوایی نرم افزارها
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       10/09/1394, 09:18

12. ## مديريت انجمن

    1. ## پیشنهادها و مسايل مديريتي

       (1 کاربر آنلاین)

       #### بخشها:

       1. - مسايل محتوايي
          - مواردی که باید منتقل شود
          - مسايل فني

       #### مدیران انجمن:

       1. مدیر فنی,
       2. منتظر منجی(عج)

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 210
       - نوشته: 5,242

       #### آخرين نوشته:

       تغییر نام کاربری برای کاربران

       توسط
       مدیر فنی
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ
       - مشاهده صفحه اصلی

       09/09/1394, 11:49

    2. ## جمع ‏بندی‏ های نهایی

       (2 کاربر آنلاین)

       #### مدیران انجمن:

       1. مدیر فنی,
       2. منتظر منجی(عج)

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 646
       - نوشته: 651

       #### آخرين نوشته:

       کشتار مسلمانان، فهم غلط داعش...

       توسط
       مدیر تدوین
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       31/06/1394, 19:13

    3. ## اطلاعيه ها و اخبار سايت

       (6 کاربر آنلاین)

       #### مدیران انجمن:

       1. مدیر فنی,
       2. منتظر منجی(عج)

       #### عملیات انجمن:

       - مشاهده RSS feed این انجمن

       #### آمار انجمن:

       - موضوع: 63
       - نوشته: 4,107

       #### آخرين نوشته:

       ܓ✿ عـرض خـیــرمــقــدم و...

       توسط
       منتظر منجی(عج)
       - نمایش مشخصات
       - مشاهده نوشته ها
       - پیام شخصی
       - مشاهده وبلاگ

       13/09/1394, 11:56

    4. ## گزارش پستهاي خلاف و موارد حذفی

       #### مدیران انجمن:

       1. مدیر فنی,
       2. منتظر منجی(عج)

       #### عملیات انجمن:

       #### آمار انجمن:

       - موضوع: 232
       - نوشته: 6,312

       #### آخرين نوشته:

       خصوصی

    5. ## بخش ویژه پاسخگویان و خادمین قرآنی

       (1 کاربر آنلاین)

       #### مدیران انجمن:

       1. مدیر فنی,
       2. منتظر منجی(عج)

       #### عملیات انجمن:

       #### آمار انجمن:

       - موضوع: 0
       - نوشته: 0

       #### آخرين نوشته:

       خصوصی

## اطلاعات آماری

### کاربران حاضر در انجمن

در این لحظه 799 کاربر در سایت آنلاین و در حال فعالیت هستند. تعداد 14 عضو و 785 مهمان

1. alone star
2. fatema9300
3. samira01
4. فدایی رهبر *
5. ملطوف امام رضا
6. محب مهدی
7. مدیر فنی
8. مدیر تدوین
9. مسلم
10. نشاط
11. به سمت خدا
12. بی ریا
13. دلاور
14. شیعه اهل بیت(ع)

### تعداد کاربران بازدید کننده از انجمن در 24 ساعت گذشته: 97

بیشترین کاربران حاضر در یک روز 201 نفر در تاریخ 30/03/1394 می باشد

- *یا عالی,
- *عرفانی*,
- :طاها:,
- arsalani,
- azv,
- ღ.Golboteh.ღ,
- ║✿║خادم زهرا║✿║,
- bahoone,
- fagatbakhodabakhodab,
- fatema9300,
- fmahmoodpoor,
- hana69317870,
- heyblog,
- kamalipedram0511,
- karbalanajaf,
- lost1,
- mehdi_hidden,
- mehrant,
- mohebbe mother,
- montazer59,
- pakalah,
- peidadali1375,
- REZA P,
- sahar.53.ir,
- samira01,
- soroush1374,
- sylar,
- tanhayi4538,
- فاطمه سادات توکلی,
- فدایی رهبر *,
- ملطوف امام رضا,
- منتظر منجی(عج),
- منتظر یوسف زهرا,
- مهدي,
- مهدی49,
- میقات,
- مبینا.,
- محمد طه,
- محب مهدی,
- مدیر فنی,
- مدیر فرهنگی,
- مدیر محتوایی نرم افزارها,
- مدیر اجرایی,
- مدیر تدوین,
- مسلم,
- معین,
- چینی چی,
- نگاه19,
- نشاط,
- هدی,
- یوسف,
- یا رقیه,
- یا صادق(ع),
- کشتی نجات,
- گلستان قرآن,
- گمنام110,
- گوگوری مگوری,
- پیام,
- yahya63,
- آرامش با یاد خدا,
- اللیل والنهار,
- ارمغان,
- به سمت خدا,
- بهشت سعادت,
- بی ریا,
- بکیر,
- خیرالبریه,
- خاتم,
- خادم الزینب,
- دلاور,
- دايي حسن,
- دختر مهربان,
- رئوف,
- ستايشگر,
- ستاره پر فروغ,
- سحرگاه,
- سعادتمند,
- شهیده,
- شیوا83,
- شیعه اهل بیت(ع),
- صدیقین,
- علی ولی زاده,
- عاشق ولایت,
- عروس مقدس,
- عظيم

### ارسال کنندگان پست در 24 ساعت اخیر

1. منتظر منجی(عج) 9
2. فدایی رهبر * 8
3. منتظر یوسف زهرا 7
4. بی ریا 6
5. خاتم 6
6. مهدی49 5
7. :طاها: 4
8. معین 4
9. arsalani 3
10. علی ولی زاده 3
11. میقات 3
12. بکیر 3
13. هدی 3
14. mehrant 2
15. ║✿║خادم زهرا║✿║ 2
16. شقایق 2
17. fmahmoodpoor 2
18. خیرالبریه 1
19. گمنام110 1
20. یا عزیز زهرا 1
21. lost1 1
22. نیلوفر 1
23. نگاه19 1
24. heyblog 1
25. نشاط 1
26. صدیقین 1
27. خادم الزینب 1

### آمار و ارقام سايت

موضوع:23,248 نوشته:643,540 کاربران:54,399 کاربران فعال:338 جدید ترین عضو sylar مجموع صلوات ها : 115427015 ❤ مجموع دلنوشته ها : 3690
مدت حضور کاربران:16 سال 2 ماه 2 هفته 6 روز 18 ساعت 31 دقيقه 54 ثانيه آمار جهانی:نمایش
وبلاگ ها:71 مطالب: 1,478 24 ساعت گذشته: 1

### راهنمای آیکون های سایت

  دارای مطلب جدید
  دارای مطلب قدیمی
  فروم یک دسته بندی است
  انجمن لینک داده شده